import 'dart:convert';
import 'package:json_annotation/json_annotation.dart';
import 'package:tautulli/utilities.dart';

part 'newsletter.g.dart';

/// Model to store information about a Tautulli newsletter.
@JsonSerializable()
class TautulliNewsletter {
    /// newsletter ID.
    @JsonKey(name: 'id')
    final int id;

    /// newsletter agent ID.
    @JsonKey(name: 'agent_id')
    final int agentId;

    /// Name of the newsletter agent.
    @JsonKey(name: 'agent_name')
    final String agentName;

    /// Label of the newsletter agent.
    @JsonKey(name: 'agent_label')
    final String agentLabel;

    /// Friendly name (description) of the newsletter.
    @JsonKey(name: 'friendly_name')
    final String friendlyName;

    /// The Crontab schedule.
    @JsonKey(name: 'cron')
    final String cron;

    /// Is the newsletter active/enabled?
    @JsonKey(name: 'active', toJson: TautulliUtilities.booleanToInteger, fromJson: TautulliUtilities.integerToBoolean)
    final bool active;

    TautulliNewsletter({
        this.id,
        this.agentId,
        this.agentName,
        this.agentLabel,
        this.friendlyName,
        this.cron,
        this.active,
    });

    /// Returns a JSON-encoded string version of this object.
    @override
    String toString() => json.encode(this.toJson());

    /// Deserialize a JSON map to a [TautulliNewsletter] object.
    factory TautulliNewsletter.fromJson(Map<String, dynamic> json) => _$TautulliNewsletterFromJson(json);
    /// Serialize a [TautulliNewsletter] object to a JSON map.
    Map<String, dynamic> toJson() => _$TautulliNewsletterToJson(this);
}
