import 'dart:convert';
import 'package:json_annotation/json_annotation.dart';
import 'package:tautulli/utilities.dart';

part 'notification_log_record.g.dart';

/// Model to store an individual notification log details from Tautulli.
@JsonSerializable(explicitToJson: true)
class TautulliNotificationLogRecord {
    /// ID of the notification.
    @JsonKey(name: 'id')
    final int id;

    @JsonKey(name: 'timestamp', toJson: TautulliUtilities.dateTimeToIntegerMilliseconds, fromJson: TautulliUtilities.millisecondsIntegerToDateTime)
    final DateTime timestamp;

    /// The session key (if applicable).
    @JsonKey(name: 'session_key')
    final int sessionKey;

    /// The content rating key (if applicable).
    @JsonKey(name: 'rating_key')
    final int ratingKey;

    /// The user's ID (if applicable).
    @JsonKey(name: 'user_id')
    final int userId;

    /// The user's username (if applicable).
    @JsonKey(name: 'user')
    final String user;

    /// The notifier ID for the notifier that triggered the notification.
    @JsonKey(name: 'notifier_id')
    final int notifierId;

    /// The agent ID for the notifier.
    @JsonKey(name: 'agent_id')
    final int agentId;

    /// The agent name for the notifier.
    @JsonKey(name: 'agent_name')
    final String agentName;

    /// The notification action that triggered the notification.
    @JsonKey(name: 'notify_action')
    final String notifyAction;

    /// The subject text of the notification.
    @JsonKey(name: 'subject_text')
    final String subjectText;

    /// The body text of the notification.
    @JsonKey(name: 'body_text')
    final String bodyText;

    /// Was the notification successfully sent?
    @JsonKey(name: 'success', toJson: TautulliUtilities.booleanToInteger, fromJson: TautulliUtilities.integerToBoolean)
    final bool success;

    TautulliNotificationLogRecord({
        this.id,
        this.timestamp,
        this.sessionKey,
        this.ratingKey,
        this.userId,
        this.user,
        this.notifierId,
        this.agentId,
        this.agentName,
        this.notifyAction,
        this.subjectText,
        this.bodyText,
        this.success,
    });

    /// Returns a JSON-encoded string version of this object.
    @override
    String toString() => json.encode(this.toJson());

    /// Deserialize a JSON map to a [TautulliNotificationLogRecord] object.
    factory TautulliNotificationLogRecord.fromJson(Map<String, dynamic> json) => _$TautulliNotificationLogRecordFromJson(json);
    /// Serialize a [TautulliNotificationLogRecord] object to a JSON map.
    Map<String, dynamic> toJson() => _$TautulliNotificationLogRecordToJson(this);
}
